@@ -26,30 +26,38 @@ class SQuADDataset(DoubleText2TextDataset):
     def __init__(
         self,
         root_dir,
+        topology_subdir,
+        graph_name,
+        static_or_dynamic="static",
         topology_builder=None,
-        topology_subdir=None,
-        graph_type="static",
+        dynamic_init_graph_name=None,
+        dynamic_init_topology_builder=None,
+        dynamic_init_topology_aux_args=None,
+        share_vocab=True,
         pretrained_word_emb_name="840B",
         pretrained_word_emb_url=None,
-        edge_strategy=None,
-        merge_strategy="tailhead",
+        pretrained_word_emb_cache_dir=None,
         max_word_vocab_size=None,
-        tokenizer=nltk.RegexpTokenizer(" ", gaps=True).tokenize,
         min_word_vocab_freq=1,
+        tokenizer=nltk.RegexpTokenizer(" ", gaps=True).tokenize,
         word_emb_size=None,
         **kwargs
     ):
         super(SQuADDataset, self).__init__(
+            graph_name,
             root_dir=root_dir,
+            static_or_dynamic=static_or_dynamic,
             topology_builder=topology_builder,
             topology_subdir=topology_subdir,
-            graph_type=graph_type,
-            edge_strategy=edge_strategy,
-            merge_strategy=merge_strategy,
-            max_word_vocab_size=max_word_vocab_size,
-            min_word_vocab_freq=min_word_vocab_freq,
+            dynamic_init_graph_name=dynamic_init_graph_name,
+            dynamic_init_topology_builder=dynamic_init_topology_builder,
+            dynamic_init_topology_aux_args=dynamic_init_topology_aux_args,
+            share_vocab=share_vocab,
             pretrained_word_emb_name=pretrained_word_emb_name,
             pretrained_word_emb_url=pretrained_word_emb_url,
+            pretrained_word_emb_cache_dir=pretrained_word_emb_cache_dir,
+            max_word_vocab_size=max_word_vocab_size,
+            min_word_vocab_freq=min_word_vocab_freq,
             tokenizer=tokenizer,
             word_emb_size=word_emb_size,
             **kwargs
